==> haskell-monad-journal-0.7.2-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.7.2
id: monad-journal-0.7.2-2LqVEnniW0OBqYGqJyXP1j
key: monad-journal-0.7.2-2LqVEnniW0OBqYGqJyXP1j
license: BSD3
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
abi: 00cd97ab4114a2a1566072621d7d71ed
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monad-journal-0.7.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/monad-journal-0.7.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/monad-journal-0.7.2
hs-libraries: HSmonad-journal-0.7.2-2LqVEnniW0OBqYGqJyXP1j
depends:
    base-4.9.0.0 either-4.4.1.1-eXXsiveugyBwHr1ieYsPQ
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.7.2-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.7.2
id: monad-journal-0.7.2-B8iviLBsIilFqeatbcEKfi
key: monad-journal-0.7.2-B8iviLBsIilFqeatbcEKfi
license: BSD3
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
abi: bc1d021b7eb199429c3b1d63c0a0af92
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monad-journal-0.7.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/monad-journal-0.7.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/monad-journal-0.7.2
hs-libraries: HSmonad-journal-0.7.2-B8iviLBsIilFqeatbcEKfi
depends:
    base-4.9.0.0 either-4.4.1.1-GPwHmmh6R1fF4eaTHkyJgU
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
